3.1.12. biosimulators_utils.sbml package — BioSimulators utils 0.1.81 documentation

# 3.1.12. biosimulators_utils.sbml package

## 3.1.12.1. Submodules

## 3.1.12.2. biosimulators_utils.sbml.utils module

Utilities for working with SBML models

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-04-05

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.sbml.utils.get_parameters_variables_for_simulation(model_filename, model_language, simulation_type, algorithm, include_compartment_sizes_in_simulation_variables=False, include_model_parameters_in_simulation_variables=False)

  Get the possible observables for a simulation of a model

  Parameters

    - model_filename (`str`) – path to model file

    - model_language (`str`) – model language (e.g., `urn:sedml:language:sbml`)

    - simulation_type (`types.Type`) – subclass of `Simulation`

    - algorithm (`str`) – KiSAO id of the algorithm for simulating the model (e.g., `KISAO_0000019` for CVODE)

    - include_compartment_sizes_in_simulation_variables (`bool`, optional) – whether to include the sizes of non-constant SBML compartments with assignment rules among the returned SED variables

    - include_model_parameters_in_simulation_variables (`bool`, optional) – whether to include the values of non-constant SBML parameters with assignment rules among the returned SED variables

  Returns

    possible attributes of a model that can be changed and their default values `list` of `Variable`: possible observables for a simulation of the model

  Return type

    `list` of `ModelAttributeChange`

## 3.1.12.3. biosimulators_utils.sbml.validation module

Utilities for validating SBML models

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-04-13

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.sbml.validation.validate_model(filename, name=None)

  Check that a model is valid

  Parameters

    - filename (`str`) – path to model

    - name (`str`, optional) – name of model for use in error messages

  Returns

    - nested `list` of `str`: nested list of errors (e.g., required ids missing or ids not unique)

    - nested `list` of `str`: nested list of errors (e.g., required ids missing or ids not unique)

  Return type

    `tuple`